#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# rfp.py
# (C) 2010-2012 by Damir Cavar <dcavar@me.com>
# Simple generation of a relative frequency profiles from token lists


import sys, os, os.path, glob


delimiterSet = ";.,!?\"()':[]\n/+-—=≤≥{}><*’”“|"


def main(fname, data):

	if not os.path.isfile(fname):
		print("Error: Not a file", fname)
		return

	try:
		inStream = open(fname, mode="r", encoding="utf-8")
		token = inStream.readline()
		while (token):
			token = token.strip()
			if token not in delimiterSet:
				data[token] = data.get(token, 0) + 1
			token = inStream.readline()
		inStream.close()
	except IOError:
		print("Cannot read from file:", fname)


def relativizeData(data):
	reldata = {}
	total = float(sum(data.values()))
	if total == 0.0:
		return reldata
	for key, value in data.items():
		reldata[key] = value/total
	return reldata


def printData(data):
	for key, value in data.items():
		print(key, value, sep="\t")


if __name__ == '__main__':
	data = {}
	for i in sys.argv[1:]:
		for j in glob.glob(i):
			main(os.path.expanduser(os.path.expandvars(j)), data)
	printData(relativizeData(data))
